@@ -16,12 +16,12 @@ fn test_new() {
 }
 
 #[inline(always)]
-pub fn clone<'b, T: Copy + Num>(v: &'b [T; 2]) -> [T; 2] {
+pub fn clone<T: Copy + Num>(v: &[T; 2]) -> [T; 2] {
     new(v[0], v[1])
 }
 
 #[inline]
-pub fn copy<'a, 'b, T: Copy + Num>(out: &'a mut [T; 2], a: &'b [T; 2]) -> &'a mut [T; 2] {
+pub fn copy<'a, T: Copy + Num>(out: &'a mut [T; 2], a: &[T; 2]) -> &'a mut [T; 2] {
     out[0] = a[0];
     out[1] = a[1];
     out
@@ -34,13 +34,13 @@ fn test_copy() {
 }
 
 #[inline]
-pub fn from_vec3<'a, 'b, T: Copy + Num>(out: &'a mut [T; 2], v: &'b [T; 3]) -> &'a mut [T; 2] {
+pub fn from_vec3<'a, T: Copy + Num>(out: &'a mut [T; 2], v: &[T; 3]) -> &'a mut [T; 2] {
     out[0] = v[0];
     out[1] = v[1];
     out
 }
 #[inline]
-pub fn from_vec4<'a, 'b, T: Copy + Num>(out: &'a mut [T; 2], v: &'b [T; 4]) -> &'a mut [T; 2] {
+pub fn from_vec4<'a, T: Copy + Num>(out: &'a mut [T; 2], v: &[T; 4]) -> &'a mut [T; 2] {
     out[0] = v[0];
     out[1] = v[1];
     out
