@@ -1,11 +1,7 @@
 use number_traits::Num;
 
 #[inline]
-pub fn div<'a, 'b, T: Copy + Num>(
-    out: &'a mut [T; 2],
-    a: &'b [T; 2],
-    b: &'b [T; 2],
-) -> &'a mut [T; 2] {
+pub fn div<'a, T: Copy + Num>(out: &'a mut [T; 2], a: &[T; 2], b: &[T; 2]) -> &'a mut [T; 2] {
     out[0] = if b[0] != T::zero() {
         a[0] / b[0]
     } else {
@@ -27,7 +23,7 @@ fn test_div() {
 }
 
 #[inline]
-pub fn sdiv<'a, 'b, T: Copy + Num>(out: &'a mut [T; 2], a: &'b [T; 2], s: T) -> &'a mut [T; 2] {
+pub fn sdiv<'a, T: Copy + Num>(out: &'a mut [T; 2], a: &[T; 2], s: T) -> &'a mut [T; 2] {
     let not_zero = s != T::zero();
     out[0] = if not_zero { a[0] / s } else { T::zero() };
     out[1] = if not_zero { a[1] / s } else { T::zero() };
