@@ -1,8 +1,8 @@
-use number_traits::{Num, Sqrt};
+use number_traits::Num;
 use div::sdiv;
 
 #[inline]
-pub fn length_values_sq<'a, 'b, T: Copy + Num>(x: T, y: T) -> T {
+pub fn length_values_sq<T: Copy + Num>(x: T, y: T) -> T {
     x * x + y * y
 }
 #[test]
@@ -11,7 +11,7 @@ fn test_length_values_sq() {
 }
 
 #[inline]
-pub fn length_values<'a, 'b, T: Copy + Num + Sqrt>(x: T, y: T) -> T {
+pub fn length_values<T: Copy + Num>(x: T, y: T) -> T {
     let lsq = length_values_sq(x, y);
     if lsq == T::zero() {
         lsq
@@ -25,7 +25,7 @@ fn test_length_values() {
 }
 
 #[inline]
-pub fn inv_length_values<'a, 'b, T: Copy + Num + Sqrt>(x: T, y: T) -> T {
+pub fn inv_length_values<T: Copy + Num>(x: T, y: T) -> T {
     let lsq = length_values_sq(x, y);
     if lsq == T::zero() {
         lsq
@@ -39,7 +39,7 @@ fn test_inv_length_values() {
 }
 
 #[inline]
-pub fn dot<'a, 'b, T: Copy + Num>(a: &'b [T; 2], b: &'b [T; 2]) -> T {
+pub fn dot<T: Copy + Num>(a: &[T; 2], b: &[T; 2]) -> T {
     a[0] * b[0] + a[1] * b[1]
 }
 #[test]
@@ -48,7 +48,7 @@ fn test_dot() {
 }
 
 #[inline]
-pub fn cross<'a, 'b, T: Copy + Num>(a: &'b [T; 2], b: &'b [T; 2]) -> T {
+pub fn cross<T: Copy + Num>(a: &[T; 2], b: &[T; 2]) -> T {
     a[0] * b[1] - a[1] * b[0]
 }
 #[test]
@@ -57,7 +57,7 @@ fn test_cross() {
 }
 
 #[inline]
-pub fn length_sq<'a, T: Copy + Num + Sqrt>(out: &'a [T; 2]) -> T {
+pub fn length_sq<T: Copy + Num>(out: &[T; 2]) -> T {
     length_values_sq(out[0], out[1])
 }
 #[test]
@@ -66,7 +66,7 @@ fn test_length_sq() {
 }
 
 #[inline]
-pub fn length<'a, T: Copy + Num + Sqrt>(out: &'a [T; 2]) -> T {
+pub fn length<T: Copy + Num>(out: &[T; 2]) -> T {
     length_values(out[0], out[1])
 }
 #[test]
@@ -75,10 +75,7 @@ fn test_length() {
 }
 
 #[inline]
-pub fn normalize<'a, 'b, T: Copy + Num + Sqrt>(
-    out: &'a mut [T; 2],
-    a: &'b [T; 2],
-) -> &'a mut [T; 2] {
+pub fn normalize<'a, T: Copy + Num>(out: &'a mut [T; 2], a: &[T; 2]) -> &'a mut [T; 2] {
     sdiv(out, a, length(a))
 }
 #[test]
