@@ -1,7 +1,7 @@
-use number_traits::{ApproxEq, Cast, Num, Signed};
+use number_traits::{Cast, Num, Signed};
 
 #[inline]
-pub fn inverse<'a, 'b, T: Copy + Signed>(out: &'a mut [T; 2], a: &'b [T; 2]) -> &'a mut [T; 2] {
+pub fn inverse<'a, T: Copy + Signed>(out: &'a mut [T; 2], a: &[T; 2]) -> &'a mut [T; 2] {
     out[0] = -a[0];
     out[1] = -a[1];
     out
@@ -15,7 +15,7 @@ fn test_inverse() {
 }
 
 #[inline]
-pub fn lerp<'a, 'b, T, F>(out: &'a mut [T; 2], a: &'b [T; 2], b: &'b [T; 2], t: F) -> &'a mut [T; 2]
+pub fn lerp<'a, T, F>(out: &'a mut [T; 2], a: &[T; 2], b: &[T; 2], t: F) -> &'a mut [T; 2]
 where
     T: Copy + Num + Cast<F>,
     F: Copy + Num + Cast<T>,
@@ -38,7 +38,7 @@ fn test_lerp() {
 }
 
 #[inline]
-pub fn perp_l<'a, 'b, T: Copy + Signed>(out: &'a mut [T; 2], a: &'b [T; 2]) -> &'a mut [T; 2] {
+pub fn perp_l<'a, T: Copy + Signed>(out: &'a mut [T; 2], a: &[T; 2]) -> &'a mut [T; 2] {
     out[0] = a[1];
     out[1] = -a[0];
     out
@@ -52,7 +52,7 @@ fn test_perp_l() {
 }
 
 #[inline]
-pub fn perp_r<'a, 'b, T: Copy + Signed>(out: &'a mut [T; 2], a: &'b [T; 2]) -> &'a mut [T; 2] {
+pub fn perp_r<'a, T: Copy + Signed>(out: &'a mut [T; 2], a: &[T; 2]) -> &'a mut [T; 2] {
     out[0] = -a[1];
     out[1] = a[0];
     out
@@ -66,11 +66,7 @@ fn test_perp_r() {
 }
 
 #[inline]
-pub fn min<'a, 'b, T: Copy + Num>(
-    out: &'a mut [T; 2],
-    a: &'b [T; 2],
-    b: &'b [T; 2],
-) -> &'a mut [T; 2] {
+pub fn min<'a, T: Copy + Num>(out: &'a mut [T; 2], a: &[T; 2], b: &[T; 2]) -> &'a mut [T; 2] {
     out[0] = if b[0] < a[0] { b[0] } else { a[0] };
     out[1] = if b[1] < a[1] { b[1] } else { a[1] };
     out
@@ -83,11 +79,7 @@ fn test_min() {
 }
 
 #[inline]
-pub fn max<'a, 'b, T: Copy + Num>(
-    out: &'a mut [T; 2],
-    a: &'b [T; 2],
-    b: &'b [T; 2],
-) -> &'a mut [T; 2] {
+pub fn max<'a, T: Copy + Num>(out: &'a mut [T; 2], a: &[T; 2], b: &[T; 2]) -> &'a mut [T; 2] {
     out[0] = if b[0] > a[0] { b[0] } else { a[0] };
     out[1] = if b[1] > a[1] { b[1] } else { a[1] };
     out
@@ -100,11 +92,11 @@ fn test_max() {
 }
 
 #[inline]
-pub fn clamp<'a, 'b, T: Copy + Num>(
+pub fn clamp<'a, T: Copy + Num>(
     out: &'a mut [T; 2],
-    a: &'b [T; 2],
-    min: &'b [T; 2],
-    max: &'b [T; 2],
+    a: &[T; 2],
+    min: &[T; 2],
+    max: &[T; 2],
 ) -> &'a mut [T; 2] {
     out[0] = if a[0] < min[0] {
         min[0]
@@ -130,7 +122,7 @@ fn test_clamp() {
 }
 
 #[inline]
-pub fn eq<'a, T: Copy + Num + ApproxEq>(a: &'a [T; 2], b: &'a [T; 2]) -> bool {
+pub fn eq<T: Copy + Num>(a: &[T; 2], b: &[T; 2]) -> bool {
     !ne(a, b)
 }
 #[test]
@@ -140,7 +132,7 @@ fn test_eq() {
 }
 
 #[inline]
-pub fn ne<'a, T: Copy + Num + ApproxEq>(a: &'a [T; 2], b: &'a [T; 2]) -> bool {
+pub fn ne<T: Copy + Num>(a: &[T; 2], b: &[T; 2]) -> bool {
     !a[0].approx_eq(&b[0]) || !a[1].approx_eq(&b[1])
 }
 #[test]
